<!DOCTYPE html>
<html>
<head>
    <title>Surat Keterangan Domisili</title>
    <style>
        body {
            font-family: 'Times New Roman', Times, serif;
            font-size: 12pt;
        }
        .header {
            text-align: center;
            margin-bottom: 20px;
        }
        .header h2 {
            margin: 0;
            font-size: 16pt;
        }
        .header p {
            margin: 0;
            font-size: 10pt;
        }
        .content {
            text-align: justify;
            line-height: 1.5;
        }
        .indent {
            text-indent: 0.5in;
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 10px;
            margin-bottom: 20px;
        }
        table td {
            padding: 5px 0;
            vertical-align: top;
        }
        .signature {
            margin-top: 40px;
            text-align: right;
        }
        .signature div {
            margin-top: 70px; /* Space for signature */
        }
        .footer {
            margin-top: 50px;
            text-align: center;
            font-size: 10pt;
        }
    </style>
</head>
<body>
    <div class="header">
        <h2>SURAT KETERANGAN DOMISILI</h2>
        <hr style="border: 1px solid black; width: 80%;">
        <p>Nomor: <?php echo e($record->nomor_surat ?? '___________________'); ?></p>
    </div>

    <div class="content">
        <p class="indent">Yang bertanda tangan di bawah ini Kepala Desa Raksajaya, Kecamatan Sodonghilir, Kabupaten Tasikmalaya, dengan ini menerangkan bahwa:</p>

        <table>
            <tr>
                <td width="30%">Nama Lengkap</td>
                <td width="5%">:</td>
                <td><?php echo e($record->nama_lengkap ?? '-'); ?></td>
            </tr>
            <tr>
                <td>NIK</td>
                <td>:</td>
                <td><?php echo e($record->nik ?? '-'); ?></td>
            </tr>
            <tr>
                <td>No. Kartu Keluarga</td>
                <td>:</td>
                <td><?php echo e($record->nomor_kartu_keluarga ?? '-'); ?></td>
            </tr>
            <tr>
                <td>Tempat, Tanggal Lahir</td>
                <td>:</td>
                <td><?php echo e($record->tempat_lahir ?? '-'); ?>, <?php echo e(\Carbon\Carbon::parse($record->tanggal_lahir ?? now())->translatedFormat('d F Y')); ?></td>
            </tr>
            <tr>
                <td>Jenis Kelamin</td>
                <td>:</td>
                <td><?php echo e($record->jenis_kelamin ?? '-'); ?></td>
            </tr>
            <tr>
                <td>Agama</td>
                <td>:</td>
                <td><?php echo e($record->agama ?? '-'); ?></td>
            </tr>
            <tr>
                <td>Status Perkawinan</td>
                <td>:</td>
                <td><?php echo e($record->status_perkawinan ?? '-'); ?></td>
            </tr>
            <tr>
                <td>Pekerjaan</td>
                <td>:</td>
                <td><?php echo e($record->pekerjaan ?? '-'); ?></td>
            </tr>
            <tr>
                <td>Alamat Domisili</td>
                <td>:</td>
                <td><?php echo e($record->alamat_saat_ini ?? '-'); ?> RT <?php echo e($record->rt ?? '-'); ?> / RW <?php echo e($record->rw ?? '-'); ?></td>
            </tr>
        </table>

        <p class="indent">Adalah benar-benar berdomisili di alamat tersebut di atas.</p>

        <p class="indent">Surat keterangan domisili ini diberikan untuk keperluan: **<?php echo e($record->keperluan ?? '-'); ?>**.</p>

        <p class="indent">Demikian surat keterangan ini dibuat dengan sebenarnya untuk dapat dipergunakan sebagaimana mestinya.</p>
    </div>

    <div class="signature">
        <p>Bogor, <?php echo e(\Carbon\Carbon::parse($record->tanggal_disetujui ?? $record->tanggal_dikeluarkan ?? now())->translatedFormat('d F Y')); ?></p>
        <p>Kepala Desa Raksajaya</p>
        <div></div> <p>( <?php echo e($record->disetujuiOleh->name ?? '_____________________'); ?> )</p>
    </div>

    <div class="footer">
        <p><i>Dokumen ini digenerate secara otomatis oleh sistem.</i></p>
    </div>
</body>
</html><?php /**PATH /home/sipf6197/laravel/resources/views/pdf/surat_keterangan_domisili.blade.php ENDPATH**/ ?>